@@ -5,6 +5,7 @@ from .message import Message
 from swibots.api.common.models.user import User
 import swibots
 
+
 class GroupChatHistory(SwitchObject):
     def __init__(
         self,
@@ -17,12 +18,14 @@ class GroupChatHistory(SwitchObject):
         self.messages = messages or []
 
     def from_json(self, data: dict) -> "GroupChatHistory":
-        self.users = User.build_from_json_list(data.get("users", []), self.app)
-        self.messages = Message.build_from_json_list(data.get("messages", []),  self.app)
+        self.users = User.build_from_json_list(
+            data.get("userInfo", []), self.app)
+        self.messages = Message.build_from_json_list(
+            data.get("message", []),  self.app)
         return self
 
     def to_json(self) -> dict:
         return {
-            "users": [user.to_json() for user in self.users],
-            "messages": [message.to_json() for message in self.messages],
+            "userInfo": [user.to_json() for user in self.users],
+            "message": [message.to_json() for message in self.messages],
         }
