@@ -26,7 +26,7 @@ class GroupDeletedEvent(CommunityEvent["GroupDeletedEvent"]):
     ):
         super().__init__(
             app=app,
-            type=EventType.GROUP_DELETE,
+            type=EventType.COMMUNITY_GROUP_DELETE,
             data=data,
             action_by=action_by,
             action_by_id=action_by_id,
