@@ -20,4 +20,4 @@ class GroupCreatedHandler(EventHandler):
         filter: Optional[Filter] = None,
         **kwargs,
     ):
-        super().__init__(EventType.GROUP_CREATE, callback, filter, **kwargs)
+        super().__init__(EventType.COMMUNITY_GROUP_CREATE, callback, filter, **kwargs)
