@@ -22,4 +22,4 @@ class GroupDeletedHandler(EventHandler):
         filter: Optional[Filter] = None,
         **kwargs,
     ):
-        super().__init__(EventType.GROUP_DELETE, callback, filter, **kwargs)
+        super().__init__(EventType.COMMUNITY_GROUP_DELETE, callback, filter, **kwargs)
