@@ -20,4 +20,4 @@ class MemberJoinedHandler(EventHandler):
         filter: Optional[Filter] = None,
         **kwargs,
     ):
-        super().__init__(EventType.MEMBER_JOIN, callback, filter, **kwargs)
+        super().__init__(EventType.COMMUNITY_MEMBER_JOIN, callback, filter, **kwargs)
